

local libTable = LibBuilder()
if not libTable then return end


local debug = libTable.debug
local Stream = libTable.classes.Stream


libTable.messageCache = {}
libTable.tabsAvailable = false


---	Creates and returns a new Stream
--	@param	destinations	Optional; list of destinations to add to the Stream.
function libTable:NewStream(...)
	local argCount = select('#', ...)
	local args = {...}
	
	local stream = Stream:New()
	
	for i=1, argCount do
		local destination = self:NewDestination(args[i])
		stream:AddDestination(destination)
	end
	
	return stream
end


---	Creates and returns a new Destination.
--	@param	value	Initial value for the Destination.
function libTable:NewDestination(value)
	return libTable.classes.Destination:New(value)
end


---	Retrieves the file-path to the function that called this method.
--	EXPERIMENTAL! SUBJECT TO CHANGE
--	@return	path	Path to the caller, or nil if not found.
function libTable:GetCallerPath()
	local stack = debugstack()
	local line = string.match(stack, '\n(.-)\n')

	--	TODO: if path gets truncated...
	local shortPath = string.match(line, 'Interface\\AddOns\\(.-):')
	
	return shortPath
end


---	Prints a string in the format 'running %s', where %s is the path to the caller's file.
--	EXPERIMENTAL! SUBJECT TO CHANGE
function libTable:Trace()
	local stack = debugstack()
	local line = string.match(stack, '\n(.-)\n')

	--	TODO: if path gets truncated...
	local shortPath = string.match(line, 'Interface\\AddOns\\(.-):')
	
	if shortPath then
		print('running', shortPath)
	else
		print(string.format('%s:Trace could not find the path to the caller.'))
	end
end
